#[non_exhaustive]pub enum Outcome {
Pass,
Warn,
Fail,
Skipped,
}Available on crate feature
client only.Expand description
How one check came out.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pass
The peer did what the specification says.
Warn
The peer did something the specification does not require but that will cause trouble.
Fail
The peer contradicts the specification.
Skipped
The check could not run — usually because the peer does not implement that module.
Implementations