pub struct Registration { /* private fields */ }Available on crate feature
client only.Expand description
Step 0: what was agreed out of band.
This credentials token along with the versions endpoint SHOULD be sent to the Sender in a secure way that is outside the scope of this protocol.
Implementations
Sourceimpl Registration
impl Registration
Sourcepub fn new(versions_url: Url, token_a: CredentialsToken) -> Self
pub fn new(versions_url: Url, token_a: CredentialsToken) -> Self
Starts a registration with the versions URL and CREDENTIALS_TOKEN_A.
Sourcepub fn with_quirks(self, quirks: Quirks) -> Self
pub fn with_quirks(self, quirks: Quirks) -> Self
Uses a specific interoperability profile while talking to this peer.
Useful when the peer is known to be a 2.1.1 implementation before its version is discovered, since those do not Base64-encode the token.