#[non_exhaustive]pub enum BridgeError {
Unsupported {
from: VersionNumber,
to: VersionNumber,
},
Decode {
version: VersionNumber,
kind: ObjectKind,
message: String,
},
}Available on crate feature
convert only.Expand description
Why a document could not be carried between two versions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
This build has no conversions between the two versions. See bridgeable.
Fields

from: VersionNumberThe version the document is written in.

to: VersionNumberThe version it was to be translated to.
Decode
The document is not the object the endpoint is supposed to carry.
Fields

version: VersionNumberThe version the document claimed to be written in.

kind: ObjectKindThe object it was expected to be.