Auth

Struct Auth 

pub struct Auth(pub AuthenticatedPeer);
Available on crate feature server only.
Extracts and authenticates the credentials token.

If the header is missing or the credentials token doesn’t match any known party then the server SHALL respond with an HTTP 401 - Unauthorized status code.

The router provides the TokenStore through axum state.

Spec: 2.3.0 transport_and_format_authorization_header

Tuple Fields

0: AuthenticatedPeer