#[non_exhaustive]pub enum Quantisation {
StepSize,
None,
}Available on crate feature
tariffs only.Expand description
Whether consumed quantities are billed in step_size blocks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StepSize
Round each quantity up to the next multiple of the applicable step_size, as OCPI 2.x
prescribes.
None
Bill the measured quantity exactly, as OCPI 3.0 will.
Implementations
Sourceimpl Quantisation
impl Quantisation
Sourcepub fn apply(self, quantity: Number, step_size: u32, unit_scale: u32) -> Number
pub fn apply(self, quantity: Number, step_size: u32, unit_scale: u32) -> Number
Rounds quantity up to the next multiple of step_size units.
unit_scale converts the quantity into the unit step_size counts: 1000 for ENERGY
(kWh measured, Wh counted) and 3600 for the time dimensions (hours measured, seconds
counted).
Consumed amounts are rounded up to the smallest multiple of
step_sizethat is greater than the consumed amount.