Module display_text
ocpi_
kit
0.2.0
Module display_
text
Module Items
Structs
In ocpi_
kit::
types
ocpi_kit
::
types
Module
display_
text
DisplayText
— a string with the language it is written in.
Structs

Display
Text
Text to be shown to an end user, tagged with its language.