#[non_exhaustive]pub struct DisplayText {
pub language: OcpiString<2>,
pub text: OcpiString<512>,
pub extensions: Extensions,
}Expand description
Text to be shown to an end user, tagged with its language.
language: Language Code ISO 639-1.text: Text to be displayed to a end user. No markup, html etc. allowed.
Spec: 2.3.0 types_displaytext_class
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.language: OcpiString<2>Language Code ISO 639-1.
text: OcpiString<512>Text to be displayed to an end user. No markup, HTML etc. allowed.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl DisplayText
impl DisplayText
Sourcepub fn new(
language: impl Into<String>,
text: impl Into<String>,
) -> Result<Self, InvalidString>
pub fn new( language: impl Into<String>, text: impl Into<String>, ) -> Result<Self, InvalidString>
Creates a DisplayText.
Errors
Returns InvalidString if the language code is not two characters or the text is
longer than 512 characters, or if either contains a control character.