CountryCodeExt

Trait CountryCodeExt 

pub trait CountryCodeExt {
    // Required method
    fn is_iso_shaped(&self) -> bool;
}
Additional checks for CountryCode values.

Required Methods

fn is_iso_shaped(&self) -> bool

Whether the value has the shape of an ISO-3166 alpha-2 code: two ASCII letters.

This does not check the code against the ISO register, which changes over time and which the OCPI spec does not require a party to know.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors