pub struct InvalidString { /* private fields */ }Expand description
Why a string could not be accepted by a strict constructor.
Implementations
Sourceimpl InvalidString
impl InvalidString
Sourcepub const fn is_too_long(&self) -> bool
pub const fn is_too_long(&self) -> bool
Whether the string was rejected only because it was too long.
Sourcepub const fn kind(&self) -> StringKind
pub const fn kind(&self) -> StringKind
The string type whose rules were broken.