pub type OcpiText = OcpiString<UNBOUNDED>;Expand description
A string with no length limit in the specification.
See UNBOUNDED.
Aliased Type
pub struct OcpiText(/* private fields */);pub type OcpiText = OcpiString<UNBOUNDED>;A string with no length limit in the specification.
See UNBOUNDED.
pub struct OcpiText(/* private fields */);