pub struct StartSessionBuilder<S: State = Empty> { /* private fields */ }Available on crate feature
v2_1_1 only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> StartSessionBuilder<S>
impl<S: State> StartSessionBuilder<S>
Sourcepub fn build(self) -> StartSessionwhere
S: IsComplete,
pub fn build(self) -> StartSessionwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn response_url(
self,
value: impl Into<Url>,
) -> StartSessionBuilder<SetResponseUrl<S>>where
S::ResponseUrl: IsUnset,
pub fn response_url(
self,
value: impl Into<Url>,
) -> StartSessionBuilder<SetResponseUrl<S>>where
S::ResponseUrl: IsUnset,
Required.
URL that the CommandResponse POST should be sent to.
Sourcepub fn token(self, value: impl Into<Token>) -> StartSessionBuilder<SetToken<S>>where
S::Token: IsUnset,
pub fn token(self, value: impl Into<Token>) -> StartSessionBuilder<SetToken<S>>where
S::Token: IsUnset,
Required.
The Token the Charge Point has to use to start a new session.
Sourcepub fn location_id(
self,
value: impl Into<OcpiString<39>>,
) -> StartSessionBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
pub fn location_id(
self,
value: impl Into<OcpiString<39>>,
) -> StartSessionBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
Required.
Location.id on which a session is to be started.
Sourcepub fn evse_uid(
self,
value: impl Into<OcpiString<39>>,
) -> StartSessionBuilder<SetEvseUid<S>>where
S::EvseUid: IsUnset,
pub fn evse_uid(
self,
value: impl Into<OcpiString<39>>,
) -> StartSessionBuilder<SetEvseUid<S>>where
S::EvseUid: IsUnset,
Sourcepub fn maybe_evse_uid(
self,
value: Option<impl Into<OcpiString<39>>>,
) -> StartSessionBuilder<SetEvseUid<S>>where
S::EvseUid: IsUnset,
pub fn maybe_evse_uid(
self,
value: Option<impl Into<OcpiString<39>>>,
) -> StartSessionBuilder<SetEvseUid<S>>where
S::EvseUid: IsUnset,
Sourcepub fn extensions(
self,
value: impl Into<Extensions>,
) -> StartSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn extensions(
self,
value: impl Into<Extensions>,
) -> StartSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
Sourcepub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> StartSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> StartSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,