pub struct Credentials {
pub token: OcpiString<64>,
pub url: Url,
pub business_details: BusinessDetails,
pub party_id: OcpiString<3>,
pub country_code: OcpiString<2>,
pub extensions: Extensions,
}Available on crate feature
v2_1_1 only.Expand description
The credentials one party gives another, in OCPI 2.1.1.
Spec: 2.1.1 credentials_credentials_object
Fields
token: OcpiString<64>The token for the other party to authenticate in your system.
url: UrlThe URL to your API versions endpoint.
business_details: BusinessDetailsDetails of this party.
party_id: OcpiString<3>CPO or eMSP ID of this party.
country_code: OcpiString<2>Country code of the country this party is operating in.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl Credentials
impl Credentials
Sourcepub fn builder() -> CredentialsBuilder
pub fn builder() -> CredentialsBuilder
Create an instance of Credentials using the builder syntax
Sourceimpl Credentials
impl Credentials
Sourcepub fn party(&self) -> Result<PartyRef, InvalidString>
pub fn party(&self) -> Result<PartyRef, InvalidString>
The single party these credentials speak for.
Errors
Returns crate::types::InvalidString if the two fields are not a usable party
reference, which can happen for a value that came off the wire.