pub struct StartSession {
pub response_url: Url,
pub token: Token,
pub location_id: CiString<36>,
pub evse_uid: Option<CiString<36>>,
pub connector_id: Option<CiString<36>>,
pub authorization_reference: Option<CiString<36>>,
pub extensions: Extensions,
}Available on crate feature
v2_2_1 only.Expand description
A request to start a charging session, in OCPI 2.2.1.
Spec: 2.2.1 mod_commands_startsession_object
Fields
response_url: UrlURL that the CommandResult POST should be sent to.
token: TokenThe Token the Charge Point has to use to start a new session.
location_id: CiString<36>Location.id on which a session is to be started.
evse_uid: Option<CiString<36>>EVSE.uid on which a session is to be started. Required when connector_id is set.
connector_id: Option<CiString<36>>Connector.id on which a session is to be started.
Reference to the authorization given by the eMSP.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl StartSession
impl StartSession
Sourcepub fn builder() -> StartSessionBuilder
pub fn builder() -> StartSessionBuilder
Create an instance of StartSession using the builder syntax