StartSessionBuilder

Struct StartSessionBuilder 

pub struct StartSessionBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature v2_2_1 only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> StartSessionBuilder<S>

pub fn build(self) -> StartSession
where S: IsComplete,

Finish building and return the requested object

pub fn response_url( self, value: impl Into<Url>, ) -> StartSessionBuilder<SetResponseUrl<S>>
where S::ResponseUrl: IsUnset,

Required.

URL that the CommandResult POST should be sent to.

pub fn token(self, value: impl Into<Token>) -> StartSessionBuilder<SetToken<S>>
where S::Token: IsUnset,

Required.

The Token the Charge Point has to use to start a new session.

pub fn location_id( self, value: impl Into<CiString<36>>, ) -> StartSessionBuilder<SetLocationId<S>>
where S::LocationId: IsUnset,

Required.

Location.id on which a session is to be started.

pub fn evse_uid( self, value: impl Into<CiString<36>>, ) -> StartSessionBuilder<SetEvseUid<S>>
where S::EvseUid: IsUnset,

Optional (Some / Option setters). EVSE.uid on which a session is to be started. Required when connector_id is set.

pub fn maybe_evse_uid( self, value: Option<impl Into<CiString<36>>>, ) -> StartSessionBuilder<SetEvseUid<S>>
where S::EvseUid: IsUnset,

Optional (Some / Option setters). EVSE.uid on which a session is to be started. Required when connector_id is set.

pub fn connector_id( self, value: impl Into<CiString<36>>, ) -> StartSessionBuilder<SetConnectorId<S>>
where S::ConnectorId: IsUnset,

Optional (Some / Option setters). Connector.id on which a session is to be started.

pub fn maybe_connector_id( self, value: Option<impl Into<CiString<36>>>, ) -> StartSessionBuilder<SetConnectorId<S>>
where S::ConnectorId: IsUnset,

Optional (Some / Option setters). Connector.id on which a session is to be started.

pub fn authorization_reference( self, value: impl Into<CiString<36>>, ) -> StartSessionBuilder<SetAuthorizationReference<S>>
where S::AuthorizationReference: IsUnset,

Optional (Some / Option setters). Reference to the authorization given by the eMSP.

pub fn maybe_authorization_reference( self, value: Option<impl Into<CiString<36>>>, ) -> StartSessionBuilder<SetAuthorizationReference<S>>
where S::AuthorizationReference: IsUnset,

Optional (Some / Option setters). Reference to the authorization given by the eMSP.

pub fn extensions( self, value: impl Into<Extensions>, ) -> StartSessionBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.

pub fn maybe_extensions( self, value: Option<impl Into<Extensions>>, ) -> StartSessionBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.