pub struct CredentialsRoleBuilder<S: State = Empty> { /* private fields */ }Available on crate feature
v2_2_1 only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CredentialsRoleBuilder<S>
impl<S: State> CredentialsRoleBuilder<S>
Sourcepub fn build(self) -> CredentialsRolewhere
S: IsComplete,
pub fn build(self) -> CredentialsRolewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn role(self, value: impl Into<Role>) -> CredentialsRoleBuilder<SetRole<S>>where
S::Role: IsUnset,
pub fn role(self, value: impl Into<Role>) -> CredentialsRoleBuilder<SetRole<S>>where
S::Role: IsUnset,
Required.
Type of role.
Sourcepub fn business_details(
self,
value: impl Into<BusinessDetails>,
) -> CredentialsRoleBuilder<SetBusinessDetails<S>>where
S::BusinessDetails: IsUnset,
pub fn business_details(
self,
value: impl Into<BusinessDetails>,
) -> CredentialsRoleBuilder<SetBusinessDetails<S>>where
S::BusinessDetails: IsUnset,
Required.
Details of this party.
Sourcepub fn party_id(
self,
value: impl Into<PartyId>,
) -> CredentialsRoleBuilder<SetPartyId<S>>where
S::PartyId: IsUnset,
pub fn party_id(
self,
value: impl Into<PartyId>,
) -> CredentialsRoleBuilder<SetPartyId<S>>where
S::PartyId: IsUnset,
Required.
CPO, eMSP (or other role) ID of this party.
Sourcepub fn country_code(
self,
value: impl Into<CountryCode>,
) -> CredentialsRoleBuilder<SetCountryCode<S>>where
S::CountryCode: IsUnset,
pub fn country_code(
self,
value: impl Into<CountryCode>,
) -> CredentialsRoleBuilder<SetCountryCode<S>>where
S::CountryCode: IsUnset,
Required.
ISO-3166 alpha-2 country code of the country this party is operating in.
Sourcepub fn extensions(
self,
value: impl Into<Extensions>,
) -> CredentialsRoleBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn extensions(
self,
value: impl Into<Extensions>,
) -> CredentialsRoleBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
Sourcepub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> CredentialsRoleBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> CredentialsRoleBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,