pub struct ClientInfo {
pub party_id: PartyId,
pub country_code: CountryCode,
pub role: Role,
pub status: ConnectionStatus,
pub last_updated: DateTime,
pub extensions: Extensions,
}Available on crate feature
v2_2_1 only.Expand description
The connection status of one party at a hub, in OCPI 2.2.1.
Spec: 2.2.1 mod_hub_client_info_hub_client_info_object
Fields
party_id: PartyIdCPO or eMSP ID of this party, as used in the credentials exchange.
country_code: CountryCodeCountry code of the country this party is operating in.
role: RoleThe role of the connected party.
status: ConnectionStatusStatus of the connection to the party.
last_updated: DateTimeTimestamp when this ClientInfo object was last updated.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl ClientInfo
impl ClientInfo
Sourcepub fn new(
party: PartyRef,
role: Role,
status: ConnectionStatus,
last_updated: DateTime,
) -> Self
pub fn new( party: PartyRef, role: Role, status: ConnectionStatus, last_updated: DateTime, ) -> Self
Creates a client info entry.
Sourcepub fn is_reachable(&self) -> bool
pub fn is_reachable(&self) -> bool
Whether messages can currently be delivered to this party.