Session

Struct Session 

pub struct Session {
Show 19 fields pub country_code: CountryCode, pub party_id: PartyId, pub id: CiString<36>, pub start_date_time: DateTime, pub end_date_time: Option<DateTime>, pub kwh: Number, pub cdr_token: CdrToken, pub auth_method: AuthMethod, pub authorization_reference: Option<CiString<36>>, pub location_id: CiString<36>, pub evse_uid: CiString<36>, pub connector_id: CiString<36>, pub meter_id: Option<OcpiString<255>>, pub currency: Currency, pub charging_periods: Vec<ChargingPeriod>, pub total_cost: Option<Price>, pub status: SessionStatus, pub last_updated: DateTime, pub extensions: Extensions,
}
Available on crate feature v2_2_1 only.
One charging session, as it stands right now, in OCPI 2.2.1.

Spec: 2.2.1 mod_sessions_session_object

Fields

country_code: CountryCode

ISO-3166 alpha-2 country code of the CPO that ‘owns’ this Session.

party_id: PartyId

ID of the CPO that ‘owns’ this Session.

id: CiString<36>

The unique id that identifies the charging session in the CPO platform.

start_date_time: DateTime

When the session became ACTIVE in the Charge Point.

end_date_time: Option<DateTime>

When the session was completed.

kwh: Number

How many kWh were charged.

cdr_token: CdrToken

Token used to start this charging session.

auth_method: AuthMethod

Method used for authentication.

authorization_reference: Option<CiString<36>>

Reference to the authorization given by the eMSP.

location_id: CiString<36>

Location.id on which the charging session is or was happening.

evse_uid: CiString<36>

EVSE.uid on which the charging session is or was happening. May be #NA.

connector_id: CiString<36>

Connector.id where the charging session is or was happening. May be #NA.

meter_id: Option<OcpiString<255>>

Optional identification of the kWh meter.

currency: Currency

ISO 4217 code of the currency used for this session.

charging_periods: Vec<ChargingPeriod>

Charging Periods that can be used to calculate and verify the total cost.

total_cost: Option<Price>

The total cost of the session.

status: SessionStatus

The status of the session.

last_updated: DateTime

Timestamp when this Session was last updated (or created).

extensions: Extensions

Undocumented JSON fields, preserved verbatim.

Implementations

Source

impl Session

pub fn builder() -> SessionBuilder

Create an instance of Session using the builder syntax

Source

impl Session

pub fn owner_party(&self) -> PartyRef

The CPO that owns this Session.

pub fn has_assigned_evse(&self) -> bool

Whether an EVSE and connector have been assigned yet.

pub fn dimension_total(&self, dimension: CdrDimensionType) -> Number

The total volume of one dimension across every charging period.