TariffBuilder

Struct TariffBuilder 

pub struct TariffBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature v2_2_1 only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> TariffBuilder<S>

pub fn build(self) -> Tariff
where S: IsComplete,

Finish building and return the requested object

pub fn country_code( self, value: impl Into<CountryCode>, ) -> TariffBuilder<SetCountryCode<S>>
where S::CountryCode: IsUnset,

Required.

ISO-3166 alpha-2 country code of the CPO that owns this Tariff.

pub fn party_id(self, value: impl Into<PartyId>) -> TariffBuilder<SetPartyId<S>>
where S::PartyId: IsUnset,

Required.

ID of the CPO that ‘owns’ this Tariff.

pub fn id(self, value: impl Into<CiString<36>>) -> TariffBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

Uniquely identifies the tariff within the CPO’s platform.

pub fn currency( self, value: impl Into<Currency>, ) -> TariffBuilder<SetCurrency<S>>
where S::Currency: IsUnset,

Required.

ISO-4217 code of the currency of this tariff.

pub fn tariff_type( self, value: impl Into<TariffType>, ) -> TariffBuilder<SetTariffType<S>>
where S::TariffType: IsUnset,

Optional (Some / Option setters). The type of the tariff. When omitted, this tariff is valid for all sessions.

pub fn maybe_tariff_type( self, value: Option<impl Into<TariffType>>, ) -> TariffBuilder<SetTariffType<S>>
where S::TariffType: IsUnset,

Optional (Some / Option setters). The type of the tariff. When omitted, this tariff is valid for all sessions.

pub fn tariff_alt_text( self, value: impl Into<Vec<DisplayText>>, ) -> TariffBuilder<SetTariffAltText<S>>
where S::TariffAltText: IsUnset,

Optional (Some / Option setters). Default: <Vec<DisplayText> as Default>::default().

Multi-language alternative tariff info texts.

pub fn maybe_tariff_alt_text( self, value: Option<impl Into<Vec<DisplayText>>>, ) -> TariffBuilder<SetTariffAltText<S>>
where S::TariffAltText: IsUnset,

Optional (Some / Option setters). Default: <Vec<DisplayText> as Default>::default().

Multi-language alternative tariff info texts.

pub fn tariff_alt_url( self, value: impl Into<Url>, ) -> TariffBuilder<SetTariffAltUrl<S>>
where S::TariffAltUrl: IsUnset,

Optional (Some / Option setters). URL to a web page explaining the tariff in human-readable form.

pub fn maybe_tariff_alt_url( self, value: Option<impl Into<Url>>, ) -> TariffBuilder<SetTariffAltUrl<S>>
where S::TariffAltUrl: IsUnset,

Optional (Some / Option setters). URL to a web page explaining the tariff in human-readable form.

pub fn min_price(self, value: impl Into<Price>) -> TariffBuilder<SetMinPrice<S>>
where S::MinPrice: IsUnset,

Optional (Some / Option setters). A Charging Session with this tariff will cost at least this amount.

pub fn maybe_min_price( self, value: Option<impl Into<Price>>, ) -> TariffBuilder<SetMinPrice<S>>
where S::MinPrice: IsUnset,

Optional (Some / Option setters). A Charging Session with this tariff will cost at least this amount.

pub fn max_price(self, value: impl Into<Price>) -> TariffBuilder<SetMaxPrice<S>>
where S::MaxPrice: IsUnset,

Optional (Some / Option setters). A Charging Session with this tariff will not cost more than this amount.

pub fn maybe_max_price( self, value: Option<impl Into<Price>>, ) -> TariffBuilder<SetMaxPrice<S>>
where S::MaxPrice: IsUnset,

Optional (Some / Option setters). A Charging Session with this tariff will not cost more than this amount.

pub fn elements( self, value: impl Into<Vec<TariffElement>>, ) -> TariffBuilder<SetElements<S>>
where S::Elements: IsUnset,

Required.

The Tariff Elements. Cardinality +.

pub fn start_date_time( self, value: impl Into<DateTime>, ) -> TariffBuilder<SetStartDateTime<S>>
where S::StartDateTime: IsUnset,

Optional (Some / Option setters). When this tariff becomes active, in UTC.

pub fn maybe_start_date_time( self, value: Option<impl Into<DateTime>>, ) -> TariffBuilder<SetStartDateTime<S>>
where S::StartDateTime: IsUnset,

Optional (Some / Option setters). When this tariff becomes active, in UTC.

pub fn end_date_time( self, value: impl Into<DateTime>, ) -> TariffBuilder<SetEndDateTime<S>>
where S::EndDateTime: IsUnset,

Optional (Some / Option setters). When this tariff stops being valid, in UTC.

pub fn maybe_end_date_time( self, value: Option<impl Into<DateTime>>, ) -> TariffBuilder<SetEndDateTime<S>>
where S::EndDateTime: IsUnset,

Optional (Some / Option setters). When this tariff stops being valid, in UTC.

pub fn energy_mix( self, value: impl Into<EnergyMix>, ) -> TariffBuilder<SetEnergyMix<S>>
where S::EnergyMix: IsUnset,

Optional (Some / Option setters). Details on the energy supplied with this tariff.

pub fn maybe_energy_mix( self, value: Option<impl Into<EnergyMix>>, ) -> TariffBuilder<SetEnergyMix<S>>
where S::EnergyMix: IsUnset,

Optional (Some / Option setters). Details on the energy supplied with this tariff.

pub fn last_updated( self, value: impl Into<DateTime>, ) -> TariffBuilder<SetLastUpdated<S>>
where S::LastUpdated: IsUnset,

Required.

Timestamp when this Tariff was last updated (or created).

pub fn extensions( self, value: impl Into<Extensions>, ) -> TariffBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.

pub fn maybe_extensions( self, value: Option<impl Into<Extensions>>, ) -> TariffBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.