CdrBuilder

Struct CdrBuilder 

pub struct CdrBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature v2_3_0 only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CdrBuilder<S>

pub fn build(self) -> Cdr
where S: IsComplete,

Finish building and return the requested object

pub fn country_code( self, value: impl Into<CountryCode>, ) -> CdrBuilder<SetCountryCode<S>>
where S::CountryCode: IsUnset,

Required.

ISO-3166 alpha-2 country code of the CPO that ‘owns’ this CDR.

pub fn party_id(self, value: impl Into<PartyId>) -> CdrBuilder<SetPartyId<S>>
where S::PartyId: IsUnset,

Required.

ID of the CPO that ‘owns’ this CDR.

pub fn id(self, value: impl Into<CiString<39>>) -> CdrBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

Uniquely identifies the CDR, unique per country_code/party_id combination.

pub fn start_date_time( self, value: impl Into<DateTime>, ) -> CdrBuilder<SetStartDateTime<S>>
where S::StartDateTime: IsUnset,

Required.

Start of the charging session, or of the reservation when there was no session.

pub fn end_date_time( self, value: impl Into<DateTime>, ) -> CdrBuilder<SetEndDateTime<S>>
where S::EndDateTime: IsUnset,

Required.

When the session was completed. Charging may have finished earlier.

pub fn session_id( self, value: impl Into<CiString<36>>, ) -> CdrBuilder<SetSessionId<S>>
where S::SessionId: IsUnset,

Optional (Some / Option setters). The Session this CDR belongs to.

Is only allowed to be omitted when the CPO has not implemented the Sessions module or this CDR is the result of a reservation that never became a charging session.

pub fn maybe_session_id( self, value: Option<impl Into<CiString<36>>>, ) -> CdrBuilder<SetSessionId<S>>
where S::SessionId: IsUnset,

Optional (Some / Option setters). The Session this CDR belongs to.

Is only allowed to be omitted when the CPO has not implemented the Sessions module or this CDR is the result of a reservation that never became a charging session.

pub fn cdr_token(self, value: impl Into<CdrToken>) -> CdrBuilder<SetCdrToken<S>>
where S::CdrToken: IsUnset,

Required.

Token used to start this charging session.

pub fn auth_method( self, value: impl Into<AuthMethod>, ) -> CdrBuilder<SetAuthMethod<S>>
where S::AuthMethod: IsUnset,

Required.

Method used for authentication. The last method used during the session.

pub fn authorization_reference( self, value: impl Into<CiString<36>>, ) -> CdrBuilder<SetAuthorizationReference<S>>
where S::AuthorizationReference: IsUnset,

Optional (Some / Option setters). Reference to the authorization given by the eMSP.

pub fn maybe_authorization_reference( self, value: Option<impl Into<CiString<36>>>, ) -> CdrBuilder<SetAuthorizationReference<S>>
where S::AuthorizationReference: IsUnset,

Optional (Some / Option setters). Reference to the authorization given by the eMSP.

pub fn booking_id( self, value: impl Into<CiString<36>>, ) -> CdrBuilder<SetBookingId<S>>
where S::BookingId: IsUnset,

Optional (Some / Option setters). The Booking this CDR also belongs to.

Is only allowed to be omitted when the Session was reserved.

Added by the OCPI 2.3.0 bookings release branch, so it is behind the bookings feature.

Spec: 2.3.0-bookings mod_cdrs_cdr_object

pub fn maybe_booking_id( self, value: Option<impl Into<CiString<36>>>, ) -> CdrBuilder<SetBookingId<S>>
where S::BookingId: IsUnset,

Optional (Some / Option setters). The Booking this CDR also belongs to.

Is only allowed to be omitted when the Session was reserved.

Added by the OCPI 2.3.0 bookings release branch, so it is behind the bookings feature.

Spec: 2.3.0-bookings mod_cdrs_cdr_object

pub fn cdr_location( self, value: impl Into<CdrLocation>, ) -> CdrBuilder<SetCdrLocation<S>>
where S::CdrLocation: IsUnset,

Required.

Where the charging session took place.

pub fn meter_id( self, value: impl Into<OcpiString<255>>, ) -> CdrBuilder<SetMeterId<S>>
where S::MeterId: IsUnset,

Optional (Some / Option setters). Identification of the meter inside the Charge Point.

pub fn maybe_meter_id( self, value: Option<impl Into<OcpiString<255>>>, ) -> CdrBuilder<SetMeterId<S>>
where S::MeterId: IsUnset,

Optional (Some / Option setters). Identification of the meter inside the Charge Point.

pub fn currency(self, value: impl Into<Currency>) -> CdrBuilder<SetCurrency<S>>
where S::Currency: IsUnset,

Required.

Currency of the CDR in ISO 4217 code.

pub fn tariffs(self, value: impl Into<Vec<Tariff>>) -> CdrBuilder<SetTariffs<S>>
where S::Tariffs: IsUnset,

Optional (Some / Option setters). Default: <Vec<Tariff> as Default>::default().

Relevant Tariffs, as they were at the start of the session.

pub fn maybe_tariffs( self, value: Option<impl Into<Vec<Tariff>>>, ) -> CdrBuilder<SetTariffs<S>>
where S::Tariffs: IsUnset,

Optional (Some / Option setters). Default: <Vec<Tariff> as Default>::default().

Relevant Tariffs, as they were at the start of the session.

pub fn charging_periods( self, value: impl Into<Vec<ChargingPeriod>>, ) -> CdrBuilder<SetChargingPeriods<S>>
where S::ChargingPeriods: IsUnset,

Required.

Charging Periods that make up this session. Cardinality +.

pub fn signed_data( self, value: impl Into<SignedData>, ) -> CdrBuilder<SetSignedData<S>>
where S::SignedData: IsUnset,

Optional (Some / Option setters). Signed metering data belonging to this session.

pub fn maybe_signed_data( self, value: Option<impl Into<SignedData>>, ) -> CdrBuilder<SetSignedData<S>>
where S::SignedData: IsUnset,

Optional (Some / Option setters). Signed metering data belonging to this session.

pub fn total_cost(self, value: impl Into<Price>) -> CdrBuilder<SetTotalCost<S>>
where S::TotalCost: IsUnset,

Required.

Total sum of all the costs of this transaction.

pub fn total_fixed_cost( self, value: impl Into<Price>, ) -> CdrBuilder<SetTotalFixedCost<S>>
where S::TotalFixedCost: IsUnset,

Optional (Some / Option setters). Total of the fixed costs, except fixed price components of parking and reservation.

pub fn maybe_total_fixed_cost( self, value: Option<impl Into<Price>>, ) -> CdrBuilder<SetTotalFixedCost<S>>
where S::TotalFixedCost: IsUnset,

Optional (Some / Option setters). Total of the fixed costs, except fixed price components of parking and reservation.

pub fn total_energy( self, value: impl Into<Number>, ) -> CdrBuilder<SetTotalEnergy<S>>
where S::TotalEnergy: IsUnset,

Required.

Total energy charged, in kWh.

pub fn total_energy_cost( self, value: impl Into<Price>, ) -> CdrBuilder<SetTotalEnergyCost<S>>
where S::TotalEnergyCost: IsUnset,

Optional (Some / Option setters). Total cost of all the energy used.

pub fn maybe_total_energy_cost( self, value: Option<impl Into<Price>>, ) -> CdrBuilder<SetTotalEnergyCost<S>>
where S::TotalEnergyCost: IsUnset,

Optional (Some / Option setters). Total cost of all the energy used.

pub fn total_time(self, value: impl Into<Number>) -> CdrBuilder<SetTotalTime<S>>
where S::TotalTime: IsUnset,

Required.

Total duration of the charging session, charging and not charging, in hours.

pub fn total_time_cost( self, value: impl Into<Price>, ) -> CdrBuilder<SetTotalTimeCost<S>>
where S::TotalTimeCost: IsUnset,

Optional (Some / Option setters). Total cost related to the duration of charging.

pub fn maybe_total_time_cost( self, value: Option<impl Into<Price>>, ) -> CdrBuilder<SetTotalTimeCost<S>>
where S::TotalTimeCost: IsUnset,

Optional (Some / Option setters). Total cost related to the duration of charging.

pub fn total_parking_time( self, value: impl Into<Number>, ) -> CdrBuilder<SetTotalParkingTime<S>>
where S::TotalParkingTime: IsUnset,

Optional (Some / Option setters). Total duration during which the EV was not charging, in hours.

pub fn maybe_total_parking_time( self, value: Option<impl Into<Number>>, ) -> CdrBuilder<SetTotalParkingTime<S>>
where S::TotalParkingTime: IsUnset,

Optional (Some / Option setters). Total duration during which the EV was not charging, in hours.

pub fn total_parking_cost( self, value: impl Into<Price>, ) -> CdrBuilder<SetTotalParkingCost<S>>
where S::TotalParkingCost: IsUnset,

Optional (Some / Option setters). Total cost related to parking, including fixed price components.

pub fn maybe_total_parking_cost( self, value: Option<impl Into<Price>>, ) -> CdrBuilder<SetTotalParkingCost<S>>
where S::TotalParkingCost: IsUnset,

Optional (Some / Option setters). Total cost related to parking, including fixed price components.

pub fn total_reservation_cost( self, value: impl Into<Price>, ) -> CdrBuilder<SetTotalReservationCost<S>>
where S::TotalReservationCost: IsUnset,

Optional (Some / Option setters). Total cost related to a reservation, including fixed price components.

pub fn maybe_total_reservation_cost( self, value: Option<impl Into<Price>>, ) -> CdrBuilder<SetTotalReservationCost<S>>
where S::TotalReservationCost: IsUnset,

Optional (Some / Option setters). Total cost related to a reservation, including fixed price components.

pub fn remark( self, value: impl Into<OcpiString<255>>, ) -> CdrBuilder<SetRemark<S>>
where S::Remark: IsUnset,

Optional (Some / Option setters). Human-readable remark, e.g. the reason a transaction was stopped.

pub fn maybe_remark( self, value: Option<impl Into<OcpiString<255>>>, ) -> CdrBuilder<SetRemark<S>>
where S::Remark: IsUnset,

Optional (Some / Option setters). Human-readable remark, e.g. the reason a transaction was stopped.

pub fn invoice_reference_id( self, value: impl Into<CiString<39>>, ) -> CdrBuilder<SetInvoiceReferenceId<S>>
where S::InvoiceReferenceId: IsUnset,

Optional (Some / Option setters). Reference to an invoice that will later be sent for this CDR.

pub fn maybe_invoice_reference_id( self, value: Option<impl Into<CiString<39>>>, ) -> CdrBuilder<SetInvoiceReferenceId<S>>
where S::InvoiceReferenceId: IsUnset,

Optional (Some / Option setters). Reference to an invoice that will later be sent for this CDR.

pub fn credit(self, value: impl Into<bool>) -> CdrBuilder<SetCredit<S>>
where S::Credit: IsUnset,

Optional (Some / Option setters). Whether this is a Credit CDR. Requires credit_reference_id.

pub fn maybe_credit( self, value: Option<impl Into<bool>>, ) -> CdrBuilder<SetCredit<S>>
where S::Credit: IsUnset,

Optional (Some / Option setters). Whether this is a Credit CDR. Requires credit_reference_id.

pub fn credit_reference_id( self, value: impl Into<CiString<39>>, ) -> CdrBuilder<SetCreditReferenceId<S>>
where S::CreditReferenceId: IsUnset,

Optional (Some / Option setters). The id of the CDR this Credit CDR corrects.

pub fn maybe_credit_reference_id( self, value: Option<impl Into<CiString<39>>>, ) -> CdrBuilder<SetCreditReferenceId<S>>
where S::CreditReferenceId: IsUnset,

Optional (Some / Option setters). The id of the CDR this Credit CDR corrects.

pub fn home_charging_compensation( self, value: impl Into<bool>, ) -> CdrBuilder<SetHomeChargingCompensation<S>>
where S::HomeChargingCompensation: IsUnset,

Optional (Some / Option setters). Whether the energy cost of this home-charging session is compensated to the EV driver.

pub fn maybe_home_charging_compensation( self, value: Option<impl Into<bool>>, ) -> CdrBuilder<SetHomeChargingCompensation<S>>
where S::HomeChargingCompensation: IsUnset,

Optional (Some / Option setters). Whether the energy cost of this home-charging session is compensated to the EV driver.

pub fn last_updated( self, value: impl Into<DateTime>, ) -> CdrBuilder<SetLastUpdated<S>>
where S::LastUpdated: IsUnset,

Required.

Timestamp when this CDR was last updated (or created).

pub fn extensions( self, value: impl Into<Extensions>, ) -> CdrBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.

pub fn maybe_extensions( self, value: Option<impl Into<Extensions>>, ) -> CdrBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.