pub struct CdrToken {
pub country_code: CountryCode,
pub party_id: PartyId,
pub uid: CiString<36>,
pub token_type: TokenType,
pub contract_id: ContractId,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
The token that started a session, as recorded in a CDR or Session.
Spec: 2.3.0 mod_cdrs_cdr_token_object
Fields
country_code: CountryCodeISO-3166 alpha-2 country code of the MSP that ‘owns’ this Token.
party_id: PartyIdID of the eMSP that ‘owns’ this Token.
uid: CiString<36>Unique ID by which this Token can be identified by the CPO’s system.
token_type: TokenTypeType of the token.
contract_id: ContractIdUniquely identifies the EV driver contract token within the eMSP’s platform.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations