pub struct SetChargingProfile {
pub charging_profile: ChargingProfile,
pub response_url: Url,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
A request to set a charging profile on a session.
Spec: 2.3.0 mod_charging_profiles_set_charging_profile_object
Fields
charging_profile: ChargingProfileLimits for the available power or current over time.
response_url: UrlURL that the ChargingProfileResult POST should be sent to.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl SetChargingProfile
impl SetChargingProfile
Sourcepub fn builder() -> SetChargingProfileBuilder
pub fn builder() -> SetChargingProfileBuilder
Create an instance of SetChargingProfile using the builder syntax