CommandResponse

Struct CommandResponse 

pub struct CommandResponse {
    pub result: CommandResponseType,
    pub timeout: u32,
    pub message: Vec<DisplayText>,
    pub extensions: Extensions,
}
Available on crate feature v2_3_0 only.
The synchronous answer to a command request.

Because OCPI does not allow/require retries, it could happen that the asynchronous result url given by the eMSP is never successfully called. … it is important for the eMSP to know the timeout on a certain command.

Spec: 2.3.0 mod_commands_commandresponse_object

Fields

result: CommandResponseType

Response from the CPO on the command request.

timeout: u32

Timeout for this command in seconds.

When the Result is not received within this timeout, the eMSP can assume that the message might never be sent.

message: Vec<DisplayText>

Human-readable description of the result, in one or more languages.

extensions: Extensions

Undocumented JSON fields, preserved verbatim.

Implementations

Source

impl CommandResponse

pub fn builder() -> CommandResponseBuilder

Create an instance of CommandResponse using the builder syntax

Source

impl CommandResponse

pub const fn timeout_duration(&self) -> Duration

The timeout as a std::time::Duration, for awaiting the asynchronous result.

pub fn expects_result(&self) -> bool

Whether a CommandResult should be expected on the response_url.

Only an ACCEPTED command has been forwarded to the Charge Point; the other outcomes are final already.