CommandResponseBuilder

Struct CommandResponseBuilder 

pub struct CommandResponseBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature v2_3_0 only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CommandResponseBuilder<S>

pub fn build(self) -> CommandResponse
where S: IsComplete,

Finish building and return the requested object

pub fn result( self, value: impl Into<CommandResponseType>, ) -> CommandResponseBuilder<SetResult<S>>
where S::Result: IsUnset,

Required.

Response from the CPO on the command request.

pub fn timeout( self, value: impl Into<u32>, ) -> CommandResponseBuilder<SetTimeout<S>>
where S::Timeout: IsUnset,

Required.

Timeout for this command in seconds.

When the Result is not received within this timeout, the eMSP can assume that the message might never be sent.

pub fn message( self, value: impl Into<Vec<DisplayText>>, ) -> CommandResponseBuilder<SetMessage<S>>
where S::Message: IsUnset,

Optional (Some / Option setters). Default: <Vec<DisplayText> as Default>::default().

Human-readable description of the result, in one or more languages.

pub fn maybe_message( self, value: Option<impl Into<Vec<DisplayText>>>, ) -> CommandResponseBuilder<SetMessage<S>>
where S::Message: IsUnset,

Optional (Some / Option setters). Default: <Vec<DisplayText> as Default>::default().

Human-readable description of the result, in one or more languages.

pub fn extensions( self, value: impl Into<Extensions>, ) -> CommandResponseBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.

pub fn maybe_extensions( self, value: Option<impl Into<Extensions>>, ) -> CommandResponseBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.