pub struct CommandResult {
pub result: CommandResultType,
pub message: Vec<DisplayText>,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
The asynchronous result, POSTed by the CPO to the response_url.
Spec: 2.3.0 mod_commands_commandresult_object
Fields
result: CommandResultTypeResult of the command request as sent by the Charge Point to the CPO.
message: Vec<DisplayText>Human-readable description of the reason, in one or more languages.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl CommandResult
impl CommandResult
Sourcepub fn builder() -> CommandResultBuilder
pub fn builder() -> CommandResultBuilder
Create an instance of CommandResult using the builder syntax