StartSession

Struct StartSession 

pub struct StartSession {
    pub response_url: Url,
    pub token: Token,
    pub location_id: CiString<36>,
    pub evse_uid: Option<CiString<36>>,
    pub connector_id: Option<CiString<36>>,
    pub authorization_reference: Option<CiString<36>>,
    pub extensions: Extensions,
}
Available on crate feature v2_3_0 only.
A request to start a charging session on a Location, EVSE or Connector.

The Token provided by the eMSP for the StartSession SHALL be authorized by the eMSP before sending it to the CPO. Therefore the CPO SHALL NOT check the validity of the Token provided before sending the request to the Charge Point.

Spec: 2.3.0 mod_commands_startsession_object

Fields

response_url: Url

URL that the CommandResult POST should be sent to.

This URL might contain a unique ID to be able to distinguish between StartSession requests.

token: Token

The Token the Charge Point has to use to start a new session.

location_id: CiString<36>

Location.id on which a session is to be started.

evse_uid: Option<CiString<36>>

EVSE.uid on which a session is to be started. Required when connector_id is set.

connector_id: Option<CiString<36>>

Connector.id on which a session is to be started.

This field is required when the capability START_SESSION_CONNECTOR_REQUIRED is set on the EVSE.

See Evse::requires_connector_id_on_start.

authorization_reference: Option<CiString<36>>

Reference to the authorization given by the eMSP, echoed in the Session and CDR.

extensions: Extensions

Undocumented JSON fields, preserved verbatim.

Implementations

Source

impl StartSession

pub fn builder() -> StartSessionBuilder

Create an instance of StartSession using the builder syntax