pub struct StopSessionBuilder<S: State = Empty> { /* private fields */ }Available on crate feature
v2_3_0 only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> StopSessionBuilder<S>
impl<S: State> StopSessionBuilder<S>
Sourcepub fn build(self) -> StopSessionwhere
S: IsComplete,
pub fn build(self) -> StopSessionwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn response_url(
self,
value: impl Into<Url>,
) -> StopSessionBuilder<SetResponseUrl<S>>where
S::ResponseUrl: IsUnset,
pub fn response_url(
self,
value: impl Into<Url>,
) -> StopSessionBuilder<SetResponseUrl<S>>where
S::ResponseUrl: IsUnset,
Required.
URL that the CommandResult POST should be sent to.
Sourcepub fn session_id(
self,
value: impl Into<CiString<36>>,
) -> StopSessionBuilder<SetSessionId<S>>where
S::SessionId: IsUnset,
pub fn session_id(
self,
value: impl Into<CiString<36>>,
) -> StopSessionBuilder<SetSessionId<S>>where
S::SessionId: IsUnset,
Required.
Session.id of the Session that is requested to be stopped.
Sourcepub fn extensions(
self,
value: impl Into<Extensions>,
) -> StopSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn extensions(
self,
value: impl Into<Extensions>,
) -> StopSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
Sourcepub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> StopSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> StopSessionBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,