pub struct CredentialsRole {
pub role: Role,
pub business_details: BusinessDetails,
pub party_id: PartyId,
pub country_code: CountryCode,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
One role a platform provides, with the party that fills it.
A platform can have the same role more than once, each with its own unique
party_idandcountry_code, for example when a CPO provides ‘white-label’ services for ‘virtual’ CPOs.
Spec: 2.3.0 credentials_credentials_role_class
Fields
role: RoleType of role.
business_details: BusinessDetailsDetails of this party.
party_id: PartyIdCPO, eMSP (or other role) ID of this party.
country_code: CountryCodeISO-3166 alpha-2 country code of the country this party is operating in.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl CredentialsRole
impl CredentialsRole
Sourcepub fn builder() -> CredentialsRoleBuilder
pub fn builder() -> CredentialsRoleBuilder
Create an instance of CredentialsRole using the builder syntax