pub struct AdditionalGeoLocation {
pub latitude: OcpiString<10>,
pub longitude: OcpiString<11>,
pub name: Option<DisplayText>,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
A geo location relevant to the Charge Point, with a name.
The geodetic system is WGS 84.
Spec: 2.3.0 mod_locations_additionalgeolocation_class
Fields
latitude: OcpiString<10>Latitude of the point in decimal degrees.
longitude: OcpiString<11>Longitude of the point in decimal degrees.
name: Option<DisplayText>Name of the point in the local language or as written at the location.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.