pub struct Connector {
pub id: CiString<36>,
pub standard: ConnectorType,
pub format: ConnectorFormat,
pub power_type: PowerType,
pub max_voltage: i32,
pub max_amperage: i32,
pub max_electric_power: Option<i32>,
pub tariff_ids: Vec<CiString<36>>,
pub terms_and_conditions: Option<Url>,
pub capabilities: Vec<ConnectorCapability>,
pub last_updated: DateTime,
pub extensions: Extensions,
}v2_3_0 only.Expand description
The socket, or cable and plug, available for the EV to use.
Spec: 2.3.0 mod_locations_connector_object
Fields
id: CiString<36>Identifier of the Connector within the EVSE.
Two Connectors may have the same id as long as they do not belong to the same EVSE.
standard: ConnectorTypeThe standard of the installed connector.
format: ConnectorFormatThe format (socket/cable) of the installed connector.
power_type: PowerTypeWhether the connector supplies AC or DC, and on how many phases.
max_voltage: i32Maximum voltage of the connector (line to neutral for AC_3_PHASE), in volt.
max_amperage: i32Maximum amperage of the connector, in ampere.
max_electric_power: Option<i32>Maximum electric power this connector can deliver, in watt.
When the maximum electric power is lower than the calculated value from
voltageandamperage, this value should be set.
tariff_ids: Vec<CiString<36>>Identifiers of the currently valid charging tariffs.
Multiple tariffs are possible, but only one of each
Tariff.typecan be active at the same time. … For a “free of charge” tariff, this field should be set and point to a defined “free of charge” tariff.
terms_and_conditions: Option<Url>URL to the operator’s terms and conditions.
capabilities: Vec<ConnectorCapability>Functionalities the connector is capable of. New in OCPI 2.3.0.
last_updated: DateTimeTimestamp when this Connector was last updated.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations