pub struct EnergyMix {
pub is_green_energy: bool,
pub energy_sources: Vec<EnergySource>,
pub environ_impact: Vec<EnvironmentalImpact>,
pub supplier_name: Option<OcpiString<64>>,
pub energy_product_name: Option<OcpiString<64>>,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
The energy mix and environmental impact of the energy supplied at a location or in a tariff.
Spec: 2.3.0 mod_locations_energymix_class
Fields
is_green_energy: boolTrue if 100% from regenerative sources: CO2 and nuclear waste are zero.
energy_sources: Vec<EnergySource>Energy sources of this location’s tariff, as category and percentage.
environ_impact: Vec<EnvironmentalImpact>Nuclear waste and CO2 exhaust of this location’s tariff.
supplier_name: Option<OcpiString<64>>Name of the energy supplier delivering the energy for this location or tariff.
energy_product_name: Option<OcpiString<64>>Name of the energy supplier’s product/tariff plan used at this location.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations