pub struct Image {
pub url: Url,
pub thumbnail: Option<Url>,
pub category: ImageCategory,
pub image_type: CiString<4>,
pub width: Option<u32>,
pub height: Option<u32>,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
An image related to an EVSE, in terms of a file name or URL.
Spec: 2.3.0 mod_locations_image_class
Fields
url: UrlURL from where the image data can be fetched through a web browser.
thumbnail: Option<Url>URL from where a thumbnail of the image can be fetched.
category: ImageCategoryDescribes what the image is used for.
image_type: CiString<4>Image type, e.g. gif, jpeg, png, svg.
width: Option<u32>Width of the full scale image.
height: Option<u32>Height of the full scale image.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations