TerminalBuilder

Struct TerminalBuilder 

pub struct TerminalBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature v2_3_0 only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> TerminalBuilder<S>

pub fn build(self) -> Terminal
where S: IsComplete,

Finish building and return the requested object

pub fn terminal_id( self, value: impl Into<CiString<36>>, ) -> TerminalBuilder<SetTerminalId<S>>
where S::TerminalId: IsUnset,

Required.

Unique ID that identifies a terminal.

pub fn customer_reference( self, value: impl Into<CiString<36>>, ) -> TerminalBuilder<SetCustomerReference<S>>
where S::CustomerReference: IsUnset,

Optional (Some / Option setters). Reference used to link the terminal to a CSMS.

pub fn maybe_customer_reference( self, value: Option<impl Into<CiString<36>>>, ) -> TerminalBuilder<SetCustomerReference<S>>
where S::CustomerReference: IsUnset,

Optional (Some / Option setters). Reference used to link the terminal to a CSMS.

pub fn party_id( self, value: impl Into<PartyId>, ) -> TerminalBuilder<SetPartyId<S>>
where S::PartyId: IsUnset,

Optional (Some / Option setters). Party ID, as an alternative to the customer reference.

pub fn maybe_party_id( self, value: Option<impl Into<PartyId>>, ) -> TerminalBuilder<SetPartyId<S>>
where S::PartyId: IsUnset,

Optional (Some / Option setters). Party ID, as an alternative to the customer reference.

pub fn country_code( self, value: impl Into<CountryCode>, ) -> TerminalBuilder<SetCountryCode<S>>
where S::CountryCode: IsUnset,

Optional (Some / Option setters). Country code, as an alternative to the customer reference.

pub fn maybe_country_code( self, value: Option<impl Into<CountryCode>>, ) -> TerminalBuilder<SetCountryCode<S>>
where S::CountryCode: IsUnset,

Optional (Some / Option setters). Country code, as an alternative to the customer reference.

pub fn address( self, value: impl Into<CiString<45>>, ) -> TerminalBuilder<SetAddress<S>>
where S::Address: IsUnset,

Optional (Some / Option setters). Street/block name and house number if available.

pub fn maybe_address( self, value: Option<impl Into<CiString<45>>>, ) -> TerminalBuilder<SetAddress<S>>
where S::Address: IsUnset,

Optional (Some / Option setters). Street/block name and house number if available.

pub fn city(self, value: impl Into<CiString<45>>) -> TerminalBuilder<SetCity<S>>
where S::City: IsUnset,

Optional (Some / Option setters). City or town.

pub fn maybe_city( self, value: Option<impl Into<CiString<45>>>, ) -> TerminalBuilder<SetCity<S>>
where S::City: IsUnset,

Optional (Some / Option setters). City or town.

pub fn postal_code( self, value: impl Into<CiString<10>>, ) -> TerminalBuilder<SetPostalCode<S>>
where S::PostalCode: IsUnset,

Optional (Some / Option setters). Postal code of the terminal.

pub fn maybe_postal_code( self, value: Option<impl Into<CiString<10>>>, ) -> TerminalBuilder<SetPostalCode<S>>
where S::PostalCode: IsUnset,

Optional (Some / Option setters). Postal code of the terminal.

pub fn state( self, value: impl Into<CiString<20>>, ) -> TerminalBuilder<SetState<S>>
where S::State: IsUnset,

Optional (Some / Option setters). State or province, only where relevant.

pub fn maybe_state( self, value: Option<impl Into<CiString<20>>>, ) -> TerminalBuilder<SetState<S>>
where S::State: IsUnset,

Optional (Some / Option setters). State or province, only where relevant.

pub fn country( self, value: impl Into<CiString<3>>, ) -> TerminalBuilder<SetCountry<S>>
where S::Country: IsUnset,

Optional (Some / Option setters). ISO 3166-1 alpha-3 code for the country of this terminal.

pub fn maybe_country( self, value: Option<impl Into<CiString<3>>>, ) -> TerminalBuilder<SetCountry<S>>
where S::Country: IsUnset,

Optional (Some / Option setters). ISO 3166-1 alpha-3 code for the country of this terminal.

pub fn coordinates( self, value: impl Into<GeoLocation>, ) -> TerminalBuilder<SetCoordinates<S>>
where S::Coordinates: IsUnset,

Optional (Some / Option setters). Coordinates of the terminal.

pub fn maybe_coordinates( self, value: Option<impl Into<GeoLocation>>, ) -> TerminalBuilder<SetCoordinates<S>>
where S::Coordinates: IsUnset,

Optional (Some / Option setters). Coordinates of the terminal.

pub fn invoice_base_url( self, value: impl Into<Url>, ) -> TerminalBuilder<SetInvoiceBaseUrl<S>>
where S::InvoiceBaseUrl: IsUnset,

Optional (Some / Option setters). Base URL of the downloadable invoice.

The full URL is this base plus the session’s authorization_reference; see InvoiceCreator::Cpo.

pub fn maybe_invoice_base_url( self, value: Option<impl Into<Url>>, ) -> TerminalBuilder<SetInvoiceBaseUrl<S>>
where S::InvoiceBaseUrl: IsUnset,

Optional (Some / Option setters). Base URL of the downloadable invoice.

The full URL is this base plus the session’s authorization_reference; see InvoiceCreator::Cpo.

pub fn invoice_creator( self, value: impl Into<InvoiceCreator>, ) -> TerminalBuilder<SetInvoiceCreator<S>>
where S::InvoiceCreator: IsUnset,

Optional (Some / Option setters). Which party creates the invoice for the eDriver.

pub fn maybe_invoice_creator( self, value: Option<impl Into<InvoiceCreator>>, ) -> TerminalBuilder<SetInvoiceCreator<S>>
where S::InvoiceCreator: IsUnset,

Optional (Some / Option setters). Which party creates the invoice for the eDriver.

pub fn reference( self, value: impl Into<CiString<36>>, ) -> TerminalBuilder<SetReference<S>>
where S::Reference: IsUnset,

Optional (Some / Option setters). Mapping value as issued by the PTP, e.g. a serial number.

pub fn maybe_reference( self, value: Option<impl Into<CiString<36>>>, ) -> TerminalBuilder<SetReference<S>>
where S::Reference: IsUnset,

Optional (Some / Option setters). Mapping value as issued by the PTP, e.g. a serial number.

pub fn location_ids( self, value: impl Into<Vec<CiString<36>>>, ) -> TerminalBuilder<SetLocationIds<S>>
where S::LocationIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<CiString<36>> as Default>::default().

All Locations assigned to this terminal.

pub fn maybe_location_ids( self, value: Option<impl Into<Vec<CiString<36>>>>, ) -> TerminalBuilder<SetLocationIds<S>>
where S::LocationIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<CiString<36>> as Default>::default().

All Locations assigned to this terminal.

pub fn evse_uids( self, value: impl Into<Vec<CiString<36>>>, ) -> TerminalBuilder<SetEvseUids<S>>
where S::EvseUids: IsUnset,

Optional (Some / Option setters). Default: <Vec<CiString<36>> as Default>::default().

All EVSEs assigned to this terminal.

pub fn maybe_evse_uids( self, value: Option<impl Into<Vec<CiString<36>>>>, ) -> TerminalBuilder<SetEvseUids<S>>
where S::EvseUids: IsUnset,

Optional (Some / Option setters). Default: <Vec<CiString<36>> as Default>::default().

All EVSEs assigned to this terminal.

pub fn last_updated( self, value: impl Into<DateTime>, ) -> TerminalBuilder<SetLastUpdated<S>>
where S::LastUpdated: IsUnset,

Required.

Timestamp when this Terminal was last updated (or created).

pub fn extensions( self, value: impl Into<Extensions>, ) -> TerminalBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.

pub fn maybe_extensions( self, value: Option<impl Into<Extensions>>, ) -> TerminalBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.