SessionBuilder

Struct SessionBuilder 

pub struct SessionBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature v2_3_0 only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> SessionBuilder<S>

pub fn build(self) -> Session
where S: IsComplete,

Finish building and return the requested object

pub fn country_code( self, value: impl Into<CountryCode>, ) -> SessionBuilder<SetCountryCode<S>>
where S::CountryCode: IsUnset,

Required.

ISO-3166 alpha-2 country code of the CPO that ‘owns’ this Session.

pub fn party_id( self, value: impl Into<PartyId>, ) -> SessionBuilder<SetPartyId<S>>
where S::PartyId: IsUnset,

Required.

ID of the CPO that ‘owns’ this Session.

pub fn id(self, value: impl Into<CiString<36>>) -> SessionBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

The unique id that identifies the charging session in the CPO platform.

pub fn start_date_time( self, value: impl Into<DateTime>, ) -> SessionBuilder<SetStartDateTime<S>>
where S::StartDateTime: IsUnset,

Required.

When the session became ACTIVE in the Charge Point.

When the session is still PENDING, this field SHALL be set to the time the Session was created at the Charge Point. When a Session goes from PENDING to ACTIVE, this field SHALL be updated to the moment the Session went to ACTIVE.

pub fn end_date_time( self, value: impl Into<DateTime>, ) -> SessionBuilder<SetEndDateTime<S>>
where S::EndDateTime: IsUnset,

Optional (Some / Option setters). When the session was completed. Charging may have finished earlier.

pub fn maybe_end_date_time( self, value: Option<impl Into<DateTime>>, ) -> SessionBuilder<SetEndDateTime<S>>
where S::EndDateTime: IsUnset,

Optional (Some / Option setters). When the session was completed. Charging may have finished earlier.

pub fn kwh(self, value: impl Into<Number>) -> SessionBuilder<SetKwh<S>>
where S::Kwh: IsUnset,

Required.

How many kWh were charged.

pub fn cdr_token( self, value: impl Into<CdrToken>, ) -> SessionBuilder<SetCdrToken<S>>
where S::CdrToken: IsUnset,

Required.

Token used to start this charging session.

pub fn auth_method( self, value: impl Into<AuthMethod>, ) -> SessionBuilder<SetAuthMethod<S>>
where S::AuthMethod: IsUnset,

Required.

Method used for authentication. This might change during a session.

pub fn authorization_reference( self, value: impl Into<CiString<36>>, ) -> SessionBuilder<SetAuthorizationReference<S>>
where S::AuthorizationReference: IsUnset,

Optional (Some / Option setters). Reference to the authorization given by the eMSP.

pub fn maybe_authorization_reference( self, value: Option<impl Into<CiString<36>>>, ) -> SessionBuilder<SetAuthorizationReference<S>>
where S::AuthorizationReference: IsUnset,

Optional (Some / Option setters). Reference to the authorization given by the eMSP.

pub fn location_id( self, value: impl Into<CiString<36>>, ) -> SessionBuilder<SetLocationId<S>>
where S::LocationId: IsUnset,

Required.

Location.id on which the charging session is or was happening.

pub fn evse_uid( self, value: impl Into<CiString<36>>, ) -> SessionBuilder<SetEvseUid<S>>
where S::EvseUid: IsUnset,

Required.

EVSE.uid on which the charging session is or was happening.

Allowed to be set to #NA when this session is created for a reservation, but no EVSE yet assigned to the driver.

pub fn connector_id( self, value: impl Into<CiString<36>>, ) -> SessionBuilder<SetConnectorId<S>>
where S::ConnectorId: IsUnset,

Required.

Connector.id where the charging session is or was happening. May be #NA.

pub fn meter_id( self, value: impl Into<OcpiString<255>>, ) -> SessionBuilder<SetMeterId<S>>
where S::MeterId: IsUnset,

Optional (Some / Option setters). Optional identification of the kWh meter.

pub fn maybe_meter_id( self, value: Option<impl Into<OcpiString<255>>>, ) -> SessionBuilder<SetMeterId<S>>
where S::MeterId: IsUnset,

Optional (Some / Option setters). Optional identification of the kWh meter.

pub fn currency( self, value: impl Into<Currency>, ) -> SessionBuilder<SetCurrency<S>>
where S::Currency: IsUnset,

Required.

ISO 4217 code of the currency used for this session.

pub fn charging_periods( self, value: impl Into<Vec<ChargingPeriod>>, ) -> SessionBuilder<SetChargingPeriods<S>>
where S::ChargingPeriods: IsUnset,

Optional (Some / Option setters). Default: <Vec<ChargingPeriod> as Default>::default().

Charging Periods that can be used to calculate and verify the total cost.

pub fn maybe_charging_periods( self, value: Option<impl Into<Vec<ChargingPeriod>>>, ) -> SessionBuilder<SetChargingPeriods<S>>
where S::ChargingPeriods: IsUnset,

Optional (Some / Option setters). Default: <Vec<ChargingPeriod> as Default>::default().

Charging Periods that can be used to calculate and verify the total cost.

pub fn total_cost( self, value: impl Into<Price>, ) -> SessionBuilder<SetTotalCost<S>>
where S::TotalCost: IsUnset,

Optional (Some / Option setters). The total cost of the session.

A total_cost of 0.00 means free of charge. When omitted … it does not imply the session is/was free of charge.

pub fn maybe_total_cost( self, value: Option<impl Into<Price>>, ) -> SessionBuilder<SetTotalCost<S>>
where S::TotalCost: IsUnset,

Optional (Some / Option setters). The total cost of the session.

A total_cost of 0.00 means free of charge. When omitted … it does not imply the session is/was free of charge.

pub fn status( self, value: impl Into<SessionStatus>, ) -> SessionBuilder<SetStatus<S>>
where S::Status: IsUnset,

Required.

The status of the session.

pub fn last_updated( self, value: impl Into<DateTime>, ) -> SessionBuilder<SetLastUpdated<S>>
where S::LastUpdated: IsUnset,

Required.

Timestamp when this Session was last updated (or created).

pub fn extensions( self, value: impl Into<Extensions>, ) -> SessionBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.

pub fn maybe_extensions( self, value: Option<impl Into<Extensions>>, ) -> SessionBuilder<SetExtensions<S>>
where S::Extensions: IsUnset,

Optional (Some / Option setters). Default: <Extensions as Default>::default().

Undocumented JSON fields, preserved verbatim.