PriceLimit

Struct PriceLimit 

pub struct PriceLimit {
    pub before_taxes: Number,
    pub after_taxes: Option<Number>,
    pub extensions: Extensions,
}
Available on crate feature v2_3_0 only.
A minimum or maximum total cost for a Charging Session. New in OCPI 2.3.0.

As the taxes on a Charging Session might be different for different parts of the Session, there might be situations where the minimum cost after taxes is reached earlier or later than the minimum price before taxes. So as a rule, they both apply.

Spec: 2.3.0 mod_tariffs_pricelimit_class

Fields

before_taxes: Number

Maximum or minimum cost excluding taxes.

after_taxes: Option<Number>

Maximum or minimum cost including taxes.

extensions: Extensions

Undocumented JSON fields, preserved verbatim.

Implementations

Source

impl PriceLimit

pub fn before_taxes(amount: Number) -> Self

A limit on the pre-tax amount only.