RequestContext

Struct RequestContext 

pub struct RequestContext {
    pub peer: AuthenticatedPeer,
    pub ids: RequestIds,
    pub routing: Option<RoutingHeaders>,
}
Available on crate feature server only.
The pieces of a request a handler is given.

Fields

peer: AuthenticatedPeer

The platform the request was authenticated as.

ids: RequestIds

The request and correlation IDs, to be echoed on the response.

routing: Option<RoutingHeaders>

The routing headers, when the module is a functional one and the peer sent them.

Implementations

Source

impl RequestContext

pub fn response_routing(&self, responder: &PartyRef) -> Option<RoutingHeaders>

The routing headers for the response to this request.

Direct response | Receiving platform provider to Requesting platform provider | Requesting-party | Receiving-party

pub fn addressed_to(&self) -> Option<&PartyRef>

The party the request was addressed to, if the peer said.

pub fn from_party(&self) -> Option<&PartyRef>

The party the request came from, if the peer said.