pub struct ReceiverEndpoint { /* private fields */ }transport only.Expand description
URLs on a module’s Receiver interface: objects owned by the client.
Client Owned Object URL definition:
{base-ocpi-url}/{end-point}/{country-code}/{party-id}/ {object-id}POST is not supported for these kinds of modules. PUT is used to send new objects to the servers.
Spec: 2.3.0 transport_and_format_client_owned_object_push
Implementations
Sourceimpl ReceiverEndpoint
impl ReceiverEndpoint
Sourcepub fn object(&self, owner: &PartyRef, object_id: &str) -> Url
pub fn object(&self, owner: &PartyRef, object_id: &str) -> Url
{base}/{country_code}/{party_id}/{object_id}.
Sourcepub fn location(
&self,
owner: &PartyRef,
location_id: &str,
evse_uid: Option<&str>,
connector_id: Option<&str>,
) -> Url
pub fn location( &self, owner: &PartyRef, location_id: &str, evse_uid: Option<&str>, connector_id: Option<&str>, ) -> Url
{locations}/{country_code}/{party_id}/{location_id}[/{evse_uid}[/{connector_id}]].
Spec: 2.3.0 mod_locations_request_parameters_msp
Sourcepub fn charging_profile(&self, session_id: &str) -> Url
pub fn charging_profile(&self, session_id: &str) -> Url
{chargingprofiles}/{session_id}[?duration=&response_url=].
The Charging Profiles Receiver interface is keyed by session, not by owning party.
Spec: 2.3.0 mod_charging_profiles_module
Sourcepub fn active_charging_profile(
&self,
session_id: &str,
duration_seconds: u64,
response_url: &Url,
) -> Url
pub fn active_charging_profile( &self, session_id: &str, duration_seconds: u64, response_url: &Url, ) -> Url
GET {chargingprofiles}/{session_id}?duration={duration}&response_url={response_url}.
Sourcepub fn clear_charging_profile(
&self,
session_id: &str,
response_url: &Url,
) -> Url
pub fn clear_charging_profile( &self, session_id: &str, response_url: &Url, ) -> Url
DELETE {chargingprofiles}/{session_id}?response_url={response_url}.
Sourcepub fn token(
&self,
owner: &PartyRef,
token_uid: &str,
token_type: Option<&str>,
) -> Url
pub fn token( &self, owner: &PartyRef, token_uid: &str, token_type: Option<&str>, ) -> Url
{tokens}/{country_code}/{party_id}/{token_uid}[?type={type}].
type: Token.type of the Token of the Token object to retrieve. Default if omitted: RFID
Spec: 2.3.0 mod_tokens_cpo_interface
Sourcepub fn payments_terminals(&self) -> Self
pub fn payments_terminals(&self) -> Self
{payments}/terminals on a CPO’s Receiver interface. See
SenderEndpoint::payments_terminals for why this is derived rather than discovered.
Sourcepub fn payments_financial_advice_confirmations(&self) -> Self
pub fn payments_financial_advice_confirmations(&self) -> Self
{payments}/financial-advice-confirmations on a CPO’s Receiver interface.