pub struct PageMeta {
pub next: Option<Url>,
pub total_count: Option<u64>,
pub limit: Option<u64>,
}Available on crate feature
transport only.Expand description
The three headers a paginated response carries.
Spec: 2.3.0 transport_and_format_paginated_response
Fields
next: Option<Url>The URL of the next page, present only when this is not the last page.
total_count: Option<u64>The total number of objects matching the query, excluding limit and offset.
limit: Option<u64>The maximum number of objects the server will return.
Note that this is an upper limit. If there are not enough remaining objects to return, fewer objects than this upper limit number will be returned, X-Limit SHALL then still show the upper limit, not the number of objects returned.
Implementations