pub enum PatchFallback {
GetThenReconcile,
PutWholeObject,
}Available on crate feature
transport only.Expand description
What a client should do after a PATCH that the peer refused.
In case a PATCH request fails, the client is expected to call the GET method to check the state of the object in the other party’s system. If the object doesn’t exist, the client should do a PUT.
Spec: 2.3.0 transport_and_format_patch
Variants
GetThenReconcile
GET the object to see what the peer has.
PutWholeObject
The object does not exist at the peer; PUT the whole object.