pub struct SignedData {
pub encoding_method: CiString<36>,
pub encoding_method_version: Option<i32>,
pub public_key: Option<OcpiString<512>>,
pub signed_values: Vec<SignedValue>,
pub url: Option<Url>,
pub extensions: Extensions,
}Available on crate feature
v2_3_0 only.Expand description
Signed metering data, for German Eichrecht and comparable regimes.
Spec: 2.3.0 mod_cdrs_signed_data_class
Fields
encoding_method: CiString<36>The name of the encoding used, as given by a company or group of companies.
Known implementations include OCMF, Alfen Eichrecht, EDL40 E-Mobility Extension and
EDL40 Mennekes.
encoding_method_version: Option<i32>Version of the encoding method, when applicable.
public_key: Option<OcpiString<512>>Public key used to sign the data, base64 encoded.
signed_values: Vec<SignedValue>One or more signed values. Cardinality +.
url: Option<Url>URL where an EV driver can check the signed data of a charging session.
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl SignedData
impl SignedData
Sourcepub fn builder() -> SignedDataBuilder
pub fn builder() -> SignedDataBuilder
Create an instance of SignedData using the builder syntax