pub struct CommandResponseBuilder<S: State = Empty> { /* private fields */ }Available on crate feature
v2_3_0 only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CommandResponseBuilder<S>
impl<S: State> CommandResponseBuilder<S>
Sourcepub fn build(self) -> CommandResponsewhere
S: IsComplete,
pub fn build(self) -> CommandResponsewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn result(
self,
value: impl Into<CommandResponseType>,
) -> CommandResponseBuilder<SetResult<S>>where
S::Result: IsUnset,
pub fn result(
self,
value: impl Into<CommandResponseType>,
) -> CommandResponseBuilder<SetResult<S>>where
S::Result: IsUnset,
Required.
Response from the CPO on the command request.
Sourcepub fn timeout(
self,
value: impl Into<u32>,
) -> CommandResponseBuilder<SetTimeout<S>>where
S::Timeout: IsUnset,
pub fn timeout(
self,
value: impl Into<u32>,
) -> CommandResponseBuilder<SetTimeout<S>>where
S::Timeout: IsUnset,
Required.
Timeout for this command in seconds.
When the Result is not received within this timeout, the eMSP can assume that the message might never be sent.
Sourcepub fn message(
self,
value: impl Into<Vec<DisplayText>>,
) -> CommandResponseBuilder<SetMessage<S>>where
S::Message: IsUnset,
pub fn message(
self,
value: impl Into<Vec<DisplayText>>,
) -> CommandResponseBuilder<SetMessage<S>>where
S::Message: IsUnset,
Sourcepub fn maybe_message(
self,
value: Option<impl Into<Vec<DisplayText>>>,
) -> CommandResponseBuilder<SetMessage<S>>where
S::Message: IsUnset,
pub fn maybe_message(
self,
value: Option<impl Into<Vec<DisplayText>>>,
) -> CommandResponseBuilder<SetMessage<S>>where
S::Message: IsUnset,
Sourcepub fn extensions(
self,
value: impl Into<Extensions>,
) -> CommandResponseBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn extensions(
self,
value: impl Into<Extensions>,
) -> CommandResponseBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
Sourcepub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> CommandResponseBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,
pub fn maybe_extensions(
self,
value: Option<impl Into<Extensions>>,
) -> CommandResponseBuilder<SetExtensions<S>>where
S::Extensions: IsUnset,