pub struct TariffRestrictions {Show 16 fields
pub start_time: Option<LocalTime>,
pub end_time: Option<LocalTime>,
pub start_date: Option<LocalDate>,
pub end_date: Option<LocalDate>,
pub min_kwh: Option<Number>,
pub max_kwh: Option<Number>,
pub min_current: Option<Number>,
pub max_current: Option<Number>,
pub min_power: Option<Number>,
pub max_power: Option<Number>,
pub min_duration: Option<u64>,
pub max_duration: Option<u64>,
pub day_of_week: Vec<DayOfWeek>,
pub reservation: Option<ReservationRestrictionType>,
pub booking: Option<BookingRestrictionType>,
pub extensions: Extensions,
}v2_3_0 only.Expand description
When a TariffElement is active during a Charging Session.
When more than one restriction is set, they are to be treated as a logical AND. So a Tariff Element is active if and only if all of the properties in its TariffRestrictions match.
Spec: 2.3.0 mod_tariffs_tariffrestrictions_class
Fields
start_time: Option<LocalTime>Start time of day in local time, e.g. 13:30; valid from this time of the day.
end_time: Option<LocalTime>End time of day in local time.
If
end_time<start_timethen the period wraps around to the next day. To stop at end of the day use: 00:00.
start_date: Option<LocalDate>Start date in local time; valid from this day, inclusive.
end_date: Option<LocalDate>End date in local time; valid until this day, exclusive.
min_kwh: Option<Number>Minimum consumed energy in kWh, inclusive.
max_kwh: Option<Number>Maximum consumed energy in kWh, exclusive.
min_current: Option<Number>Sum of the minimum current over all phases, in A, inclusive.
max_current: Option<Number>Sum of the maximum current over all phases, in A, exclusive.
min_power: Option<Number>Minimum power in kW, inclusive.
max_power: Option<Number>Maximum power in kW, exclusive.
min_duration: Option<u64>Minimum duration in seconds the Charging Session must last, inclusive.
max_duration: Option<u64>Maximum duration in seconds the Charging Session must last, exclusive.
day_of_week: Vec<DayOfWeek>Which days of the week this Tariff Element is active.
reservation: Option<ReservationRestrictionType>When present, this Tariff Element describes reservation costs.
booking: Option<BookingRestrictionType>bookings only.When present, this Tariff Element describes booking costs.
Added by the OCPI 2.3.0 bookings release branch, so it is behind the bookings feature.
Spec: 2.3.0-bookings mod_tariffs_tariffrestrictions_class
extensions: ExtensionsUndocumented JSON fields, preserved verbatim.
Implementations
Sourceimpl TariffRestrictions
impl TariffRestrictions
Sourcepub fn builder() -> TariffRestrictionsBuilder
pub fn builder() -> TariffRestrictionsBuilder
Create an instance of TariffRestrictions using the builder syntax
Sourceimpl TariffRestrictions
impl TariffRestrictions
Sourcepub fn is_unrestricted(&self) -> bool
pub fn is_unrestricted(&self) -> bool
Whether no restriction at all is set, making this the element’s fallback.
It is advised to always add a “default” Price Component per dimension. This can be achieved by adding a Tariff Element without restrictions after all other occurrences.
Sourcepub const fn is_reservation(&self) -> bool
pub const fn is_reservation(&self) -> bool
Whether this element prices a reservation rather than a charging session.